==> captchaimageclick_7.64_en.zip: captchaimageclick/CaptchaImageClick_FunCaptcha_interface.js <==
<div class="container-fluid">
<%= _.template($('#input_constructor').html())({id:"hkkxpfjt", description:tr("Captcha Selector"), default_selector: "string", disable_expression:true, disable_int:true, value_string: ">CSS> iframe[src*='arkose'], iframe[data-src*='octocaptcha']>FRAME> >CSS> iframe>FRAME> >CSS> #game-core-frame>FRAME> >CSS> button[data-theme*='verifyButton']", help: {description: tr("In this field, you must select your captcha selector, all 3 types of selectors are supported (CSS, MATCH, XPATH). All you need to do is select an element (selector) that triggers a captcha window, such as the 'next' button on the Microsoft mailbox registration form or the 'Verify' button on the Twitter registration form. Note that the default selector from this action will work for 80% of captchas Game_Box type.")} }) %>
<%= _.template($('#input_constructor').html())({id:"nrfihcrs", description:tr("Solve Method"), default_selector: "string", variants: ["Cap.Guru [Russian Server]", "Cap.Guru [German Server]", "Cap.Guru [Finland Server]", "Cap.Guru [Asian Server]"], disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this string you need to specify which of the cap.guru servers you want to send your captcha to. Please note, that captcha solving requests are not sent through a proxy, but directly from the Internet connection of your PC or server. If you observe problems with access to one of the servers, then change the solution server in the settings. It is recommended to use the RU server if you solve captcha on a server or PC from Russia, if your server is located outside of Russia, then it is recommended to use a server in Germany for solving.")} }) %>
<%= _.template($('#input_constructor').html())({id:"lppiusiv", description:tr("Secret API Key"), default_selector: "string", disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this field, you must specify the secret API key for your solution method, this key must be purchased at the recognition service https://cap.guru. Example: 1ceb81e1cbd343b136bcc3975f914dd1")} }) %>
<div style="margin-left: 20px;">
<input type="checkbox" id="AdvancedCheck" onchange="$('#Advanced').toggle()" />
<label for="AdvancedCheck" class="tr" >Advanced settings.</label>
</div>
<span id="Advanced" style="display:none">
<%= _.template($('#input_constructor').html())({id:"rmhscobm", description:tr("Click speed"), default_selector: "string", variants: ["Slow","Normal","Fast","Very Fast","Extreme"], disable_expression:true, disable_int:true, value_string: "Slow", help: {description: tr("This setting changes the behavior of mouse movement speed in the module and captcha click speed, by default the default speed is used, which is set globally in BAS."), examples: [{ code: "Slow", description: tr("standard mouse movement and click speed")},{ code: "Fast", "description": tr("accelerated x3 mouse movement and click speed")},{ code: "Extreme", "description": tr("instant x5 mouse movement and click speed")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"bwvufkyg", description:tr("Max Limit Task"), default_selector: "int", disable_string:true, value_number: 10, min_number:0, max_number:100, help: {description: tr("The maximum number of captcha jobs is the limit above which the module will not solve FunCaptcha. If the number of captcha jobs exceeds this limit, the module will return an error - job limit exceeded. This is necessary to avoid unnecessary load on the captcha service balance, as well as to avoid situations when the module will take too long to solve captcha due to a large number of jobs."), examples: [{ code: "5", description: tr("Only solve captchas with less than 5 tasks")},{ code: "10", "description": tr("Only solve captchas with less than 10 tasks")},{ code: "15", "description": tr("Only solve captchas with less than 15 tasks")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"acnxhkvo", description:tr("Enable debug mode?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting is needed to enable detailed logging of all module actions. It is primarily intended for the module developer and will most likely be unnecessary for you. However, if issues arise with the module, enable this mode to generate a detailed bug report."),examples: [{ code: "true", description: tr("enable debug mode")},{ code: "false", "description": tr("disable debug mode")}]}}) %>
</span>
</div>
<div class="tooltipinternal">
<div class="tr tooltip-paragraph-first-fold">Solve <span style="color: #FF00FF;">Arkose FunCaptcha</span> any type <code>(Game_Item, Game_Tile, Game_Box, Game_Children, Game_Lite)</code>, using the image-clicking method.</div>
<div class="tr tooltip-paragraph-fold"><code>Note! In order to solve this captcha, you need to select the button selector on the site that opens the window with the captcha and place it on the selector field in the module settings.</code></div>
<div class="tr tooltip-paragraph-fold"><code>Please note!</code> In order to solve this capcha, you need to resolve the cache in the current thread, you can do this here: the 'Network' module - the 'Allow cache' action. You must create 3 such actions with the following mask - <code>*/rtig/image*</code> and <code>*/fc/gfc*</code> and <code>*blob*</code>.</div>
<div class="tr tooltip-paragraph-fold">You need to place these actions at the beginning of the template, for example, after loading the page with the site where you collected the captcha.</div>
<div class="tr tooltip-paragraph-fold">This action allows you to solve the captcha before successful completion - a green checkmark. All you have to do is select the element (selector) that triggers the captcha solution and place it in the selector field.</div>
<div class="tr tooltip-paragraph-fold">This can be, for example, the 'Next' button on the Microsoft mail registration form or the 'Get verified' button on the Twitter registration form.</div>
<div class="tr tooltip-paragraph-fold">This action performs automatic clicks on image numbers or coordinates, takes a screenshot of the image and sends it to the service or program you specified by the capch solution. There is no need to perform any additional actions.</div>
<div class="tr tooltip-paragraph-fold">This solution method is convenient in that you do not need to search for how to call 'callback' on the site, study complex JavaScripts in order to successfully pass the captcha solution.</div>
<div class="tr tooltip-paragraph-fold">Pay attention! This action does not create any 'dangerous code' inside the browser and does not break other types of captcha on sites, as the actions to solve captcha from the context menu do.</div>
<div class="tr tooltip-paragraph-fold">This means that you do not need to constantly disable or enable this module in your scripts for fear of sanctions from the site. For example, when you warm up a profile, this action will not create any new properties of the window object or even replace the current ones.</div>
<div class="tr tooltip-paragraph-last-fold">To speed up the solution of captcha, it is recommended to use good proxies (mobile or resident), as well as a warmed-up profile. In this case, Arkose Labs can give you only 1 square with images before the captcha is successfully solved.</div>
</div>
<%= _.template($('#back').html())({action:"executeandadd", visible:true}) %>

==> captchaimageclick_7.81_en.zip: captchaimageclick/CaptchaImageClick_FunCaptcha_interface.js <==
<div class="container-fluid">
<%= _.template($('#input_constructor').html())({id:"hkkxpfjt", description:tr("Captcha Selector"), default_selector: "string", disable_expression:true, disable_int:true, value_string: ">CSS> iframe[src*='arkose'], iframe[data-src*='octocaptcha']>FRAME> >CSS> iframe>FRAME> >CSS> #game-core-frame>FRAME> >CSS> button[data-theme*='verifyButton']", help: {description: tr("In this field, you must select your captcha selector, all 3 types of selectors are supported (CSS, MATCH, XPATH). All you need to do is select an element (selector) that triggers a captcha window, such as the 'next' button on the Microsoft mailbox registration form or the 'Verify' button on the Twitter registration form. Note that the default selector from this action will work for 80% of captchas Game_Box type.")} }) %>
<%= _.template($('#input_constructor').html())({id:"nrfihcrs", description:tr("Solve Method"), default_selector: "string", variants: ["Cap.Guru [Russian Server]", "Cap.Guru [German Server]", "Cap.Guru [Finland Server]", "Cap.Guru [Asian Server]"], disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this string you need to specify which of the cap.guru servers you want to send your captcha to. Please note, that captcha solving requests are not sent through a proxy, but directly from the Internet connection of your PC or server. If you observe problems with access to one of the servers, then change the solution server in the settings. It is recommended to use the RU server if you solve captcha on a server or PC from Russia, if your server is located outside of Russia, then it is recommended to use a server in Germany for solving.")} }) %>
<%= _.template($('#input_constructor').html())({id:"lppiusiv", description:tr("Secret API Key"), default_selector: "string", disable_expression:true, disable_int:true, value_string: "", help: {description: tr("In this field, you must specify the secret API key for your solution method, this key must be purchased at the recognition service https://cap.guru. Example: 1ceb81e1cbd343b136bcc3975f914dd1")} }) %>
<div style="margin-left: 20px;">
<input type="checkbox" id="AdvancedCheck" onchange="$('#Advanced').toggle()" />
<label for="AdvancedCheck" class="tr" >Advanced settings.</label>
</div>
<span id="Advanced" style="display:none">
<%= _.template($('#input_constructor').html())({id:"rmhscobm", description:tr("Click speed"), default_selector:"string",variants:["Slow","Normal","Fast","Very Fast","Extreme","Custom"],disable_expression:true,disable_int:true,value_string:"Slow",help:{description:tr("This setting changes the behavior of mouse movement speed in the module and captcha click speed, by default the default speed is used, which is set globally in BAS."),examples:[{code:"Slow",description:tr("standard mouse movement and click speed")},{code:"Fast",description:tr("accelerated x3 mouse movement and click speed")},{code:"Extreme",description:tr("instant x5 mouse movement and click speed")},{code:"Custom:100:3:2.5",description:tr("custom speed setting: SPEED:GRAVITY:DEVIATION, e.g. Custom:100:3:2.5")} ]}}) %>	
<%= _.template($('#input_constructor').html())({id:"bwvufkyg", description:tr("Max Limit Task"), default_selector: "int", disable_string:true, value_number: 10, min_number:0, max_number:100, help: {description: tr("The maximum number of captcha jobs is the limit above which the module will not solve FunCaptcha. If the number of captcha jobs exceeds this limit, the module will return an error - job limit exceeded. This is necessary to avoid unnecessary load on the captcha service balance, as well as to avoid situations when the module will take too long to solve captcha due to a large number of jobs."), examples: [{ code: "5", description: tr("Only solve captchas with less than 5 tasks")},{ code: "10", "description": tr("Only solve captchas with less than 10 tasks")},{ code: "15", "description": tr("Only solve captchas with less than 15 tasks")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"acnxhkvo", description:tr("Enable debug mode?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting is needed to enable detailed logging of all module actions. It is primarily intended for the module developer and will most likely be unnecessary for you. However, if issues arise with the module, enable this mode to generate a detailed bug report."),examples: [{ code: "true", description: tr("enable debug mode")},{ code: "false", "description": tr("disable debug mode")}]}}) %>
<%= _.template($('#input_constructor').html())({id:"zntgralpw", description:tr("Disable warnings?"), default_selector: "expression", variants: [true, false], disable_int:true, disable_string:true, value_string: false, help: {description: tr("This setting controls the version validity check before the module starts. When the module is launched, it checks whether the installed version is up to date. The result of the check (whether the version is current or not) is written to the log file. This behavior can be disabled if needed."),examples: [{ code: "true", description: tr("disable warnings")},{ code: "false", "description": tr("enable warnings")}]}}) %>
</span>
</div>
<div class="tooltipinternal">
<div class="tr tooltip-paragraph-first-fold">Solve <span style="color: #FF00FF;">Arkose FunCaptcha</span> any type <code>(Game_Item, Game_Tile, Game_Box, Game_Children, Game_Lite)</code>, using the method of clicking on the image.</div>
<div class="tr tooltip-paragraph-fold"><code>Note! In order to solve this captcha, you need to select the button selector on the site that opens the window with the captcha and place it on the selector field in the module settings.</code></div>
<div class="tr tooltip-paragraph-fold"><code>Important note: to solve this type of captcha, you need to create an action that enables caching with the parameter set to true for your captcha.</code></div>
<div class="tr tooltip-paragraph-fold">This action allows you to solve the captcha before successful completion - a green checkmark. All you have to do is select the element (selector) that triggers the captcha solution and place it in the selector field.</div>
<div class="tr tooltip-paragraph-fold">This can be, for example, the 'Next' button on the Microsoft mail registration form or the 'Get verified' button on the Twitter registration form.</div>
<div class="tr tooltip-paragraph-fold">This action performs automatic clicks on image numbers or coordinates, takes a screenshot of the image and sends it to the service or program you specified by the capch solution. There is no need to perform any additional actions.</div>
<div class="tr tooltip-paragraph-fold">This solution method is convenient in that you do not need to search for how to call 'callback' on the site, study complex JavaScripts in order to successfully pass the captcha solution.</div>
<div class="tr tooltip-paragraph-fold">Pay attention! This action does not create any 'dangerous code' inside the browser and does not break other types of captcha on sites, as the actions to solve captcha from the context menu do.</div>
<div class="tr tooltip-paragraph-fold">This means that you do not need to constantly disable or enable this module in your scripts for fear of sanctions from the site. For example, when you warm up a profile, this action will not create any new properties of the window object or even replace the current ones.</div>
<div class="tr tooltip-paragraph-last-fold">To speed up the solution of captcha, it is recommended to use good proxies (mobile or resident), as well as a warmed-up profile. In this case, Arkose Labs can give you only 1 square with images before the captcha is successfully solved.</div>
</div>
<%= _.template($('#back').html())({action:"executeandadd", visible:true}) %>
